import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:techbusiness/models/admission_data_sheet_model.dart';
import 'package:techbusiness/utils/constants.dart';

class DetailAdmissionsUI extends StatefulWidget {
  final AdmissionDataSheet admissionDataSheet;

  const DetailAdmissionsUI({Key key, this.admissionDataSheet}) : super(key: key);

  @override
  DetailAdmissionsUiState createState() => DetailAdmissionsUiState();
}

class DetailAdmissionsUiState extends State<DetailAdmissionsUI> with SingleTickerProviderStateMixin {
  final GlobalKey<ScaffoldState> _scaffoldKey = GlobalKey<ScaffoldState>();

  AdmissionDataSheet admissionDataSheet;

  @override
  void dispose() {
    super.dispose();
  }

  @override
  void initState() {
    super.initState();
    admissionDataSheet = widget.admissionDataSheet;
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        key: _scaffoldKey,
        backgroundColor: Theme.of(context).colorScheme.background,
        body: Stack(
          children: [_buildContainer(), builderInfo(), _appBar()],
        ));
  }

  Widget _appBar() {
    return Positioned(
      top: 0.0,
      left: 0.0,
      right: 0.0,
      child: AppBar(
        backgroundColor: Colors.transparent,
        elevation: 0,
        title: Text(Constants.appBarDetailEquipment),
        centerTitle: true,
      ),
    );
  }

  Widget _buildContainer() {
    return Container(
        decoration: BoxDecoration(
          gradient: LinearGradient(colors: <Color>[
            Theme.of(context).colorScheme.primaryVariant,
            Theme.of(context).colorScheme.primary,
          ]),
          boxShadow: [
            BoxShadow(
              color: Colors.grey.withOpacity(0.5),
              spreadRadius: 5,
              blurRadius: 7,
              offset: Offset(0, 3), // changes position of shadow
            ),
          ],
        ),
        height: MediaQuery.of(context).size.height * 0.3);
  }

  Widget builderInfo() {
    return Container(
      height: MediaQuery.of(context).size.height * 0.80,
      margin: EdgeInsets.only(left: 15.0, right: 15.0, top: 125.0),
      child: Card(
        elevation: 4,
        color: Theme.of(context).colorScheme.onError,
        child: Padding(
          padding: const EdgeInsets.symmetric(vertical: 5, horizontal: 8),
          child: SingleChildScrollView(
            child: Column(
              children: [
                itemInfo('Id: ', admissionDataSheet.id.toString()),
                Divider(),
                itemInfo('Reason: ', admissionDataSheet.reason),
                Divider(),
                itemInfo('Observation: ', admissionDataSheet.observation),
                Divider(),
                itemInfo('Date: ', admissionDataSheet.date),
                // Divider(),
                // itemInfo('Type: ', equipment.type),
                // Divider(),
                // itemInfo('Ram: ', equipment.ram),
                // Divider(),
                // itemInfo('Processor: ', equipment.processor),
                // Divider(),
                // itemInfo('Board: ', equipment.board),
                // Divider(),
                // itemInfo('Status: ', equipment.status)
              ],
            ),
          ),
        ),
      ),
    );
  }

  Widget itemInfo(String label, String value) {
    return ListTile(
      title: Text(label, style: TextStyle(fontWeight: FontWeight.bold ),),
      subtitle: Text(value),
    );
  }
}
