import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:techbusiness/bloc/admission_data_sheet_bloc.dart';
import 'package:techbusiness/models/admission_data_sheet_model.dart';
import 'package:techbusiness/ui/widget/ProgressIndicatorCustom.dart';
import 'package:techbusiness/ui/widget/custom_item_menu.dart';
import 'package:techbusiness/utils/constants.dart';

import '../../../navegator_techbusiness.dart';

class DetailAdmissionUI extends StatefulWidget {
  final int id;

  const DetailAdmissionUI({Key key, this.id}) : super(key: key);

  @override
  DetailAdmissionUiState createState() => DetailAdmissionUiState();
}

class DetailAdmissionUiState extends State<DetailAdmissionUI> with SingleTickerProviderStateMixin {
  final GlobalKey<ScaffoldState> _scaffoldKey = GlobalKey<ScaffoldState>();

  int id;
  AdmissionDataSheetBloc _admissionDataSheetBloc;
  AdmissionDataSheet admission;

  @override
  void dispose() {
    super.dispose();
    _admissionDataSheetBloc.dispose();
  }

  @override
  void initState() {
    super.initState();
    id = widget.id;
    _admissionDataSheetBloc = AdmissionDataSheetBloc();
    SchedulerBinding.instance.addPostFrameCallback((_) async {
      showIndicator(context);
      await _admissionDataSheetBloc.loadDataAdmission(id);
      admission = _admissionDataSheetBloc.apiResponse.payload as AdmissionDataSheet;
      Navigator.of(context).pop();
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        key: _scaffoldKey,
        appBar: _appBar(),
        backgroundColor: Theme.of(context).colorScheme.background,
        body: Column(
          children: [_buildStream()],
        ));
  }

  Widget _appBar() {
    return AppBar(
      leading: IconButton(
        icon: Icon(Icons.arrow_back_ios_rounded),
        onPressed: () => Navigator.of(context).pop(),
      ),
      centerTitle: true,
      bottom: PreferredSize(
          preferredSize: Size.fromHeight(40.0),
          child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [Padding(padding: EdgeInsets.all(16.0), child: _title())])),
    );
  }

  Widget _title() {
    return Container(
      child: Text(Constants.appBarDetailAdmission,
          style:
              TextStyle(fontSize: 18, fontWeight: FontWeight.bold, color: Theme.of(context).colorScheme.onSecondary)),
    );
  }

  Widget _buildStream() {
    return Container(
      margin: EdgeInsets.only(left: 10.0, right: 10.0, top: 15.0),
      child: Card(
        elevation: 4,
        color: Theme.of(context).colorScheme.onError,
        child: Padding(
            padding: EdgeInsets.symmetric(vertical: 25, horizontal: 5),
            child: SingleChildScrollView(
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.center,
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                children: [
                  CustomItemMenu(
                      icon: Icons.computer,
                      label: 'Info Equipo',
                      actionPress: () {
                        TechBusinessNavigator.goToEquipmentDetail(context, admission.equipment);
                      }),
                  Divider(),
                  CustomItemMenu(
                      icon: Icons.group,
                      label: 'Info Cliente',
                      actionPress: () {
                        TechBusinessNavigator.goToCustomerDetail(context, admission.customer);
                      }),
                  Divider(),
                  CustomItemMenu(
                      icon: Icons.assignment_turned_in_rounded,
                      label: 'Ficha de ingreso',
                      actionPress: () {
                        TechBusinessNavigator.goToAdmissionsDetail(context, admission);
                      })
                ],
              ),
            )),
      ),
    );
  }
}
